aboutsummaryrefslogtreecommitdiffstats
path: root/guava/src/com/google/common/collect/AbstractSetMultimap.java
diff options
context:
space:
mode:
Diffstat (limited to 'guava/src/com/google/common/collect/AbstractSetMultimap.java')
-rw-r--r--guava/src/com/google/common/collect/AbstractSetMultimap.java10
1 files changed, 3 insertions, 7 deletions
diff --git a/guava/src/com/google/common/collect/AbstractSetMultimap.java b/guava/src/com/google/common/collect/AbstractSetMultimap.java
index e43d8b1..fe68470 100644
--- a/guava/src/com/google/common/collect/AbstractSetMultimap.java
+++ b/guava/src/com/google/common/collect/AbstractSetMultimap.java
@@ -26,14 +26,14 @@ import javax.annotation.Nullable;
/**
* Basic implementation of the {@link SetMultimap} interface. It's a wrapper
* around {@link AbstractMapBasedMultimap} that converts the returned collections into
* {@code Sets}. The {@link #createCollection} method must return a {@code Set}.
*
* @author Jared Levy
*/
@GwtCompatible
abstract class AbstractSetMultimap<K, V>
- extends AbstractMapBasedMultimap<K, V> implements SetMultimap<K, V> {
+ extends AbstractMultimap<K, V> implements SetMultimap<K, V> {
/**
* Creates a new multimap that uses the provided map.
*
@@ -46,10 +46,6 @@ abstract class AbstractSetMultimap<K, V>
@Override abstract Set<V> createCollection();
- @Override Set<V> createUnmodifiableEmptyCollection() {
- return ImmutableSet.of();
- }
-
// Following Javadoc copied from SetMultimap.
/**
@@ -117,7 +113,7 @@ abstract class AbstractSetMultimap<K, V>
* @return {@code true} if the method increased the size of the multimap, or
* {@code false} if the multimap already contained the key-value pair
*/
- @Override public boolean put(@Nullable K key, @Nullable V value) {
+ @Override public boolean put(K key, V value) {
return super.put(key, value);
}
@@ -26,14 +26,14 @@ import javax.annotation.Nullable;
/**
* Basic implementation of the {@link SetMultimap} interface. It's a wrapper
- * around {@link AbstractMapBasedMultimap} that converts the returned collections into
+ * around {@link AbstractMultimap} that converts the returned collections into
* {@code Sets}. The {@link #createCollection} method must return a {@code Set}.
*